==> ml-vision-6.4.0.tgz: package/README.md <==
<p align="center">
  <a href="https://rnfirebase.io">
    <img width="160px" src="https://i.imgur.com/JIyBtKW.png"><br/>
  </a>
  <h2 align="center">React Native Firebase - ML Kit Vision</h2>
</p>

<p align="center">
  <a href="https://api.rnfirebase.io/coverage/ml-vision/detail"><img src="https://api.rnfirebase.io/coverage/ml-vision/badge?style=flat-square" alt="Coverage"></a>
  <a href="https://www.npmjs.com/package/@react-native-firebase/ml-vision"><img src="https://img.shields.io/npm/dm/@react-native-firebase/ml-vision.svg?style=flat-square" alt="NPM downloads"></a>
  <a href="https://www.npmjs.com/package/@react-native-firebase/ml-vision"><img src="https://img.shields.io/npm/v/@react-native-firebase/ml-vision.svg?style=flat-square" alt="NPM version"></a>
  <a href="/LICENSE"><img src="https://img.shields.io/npm/l/react-native-firebase.svg?style=flat-square" alt="License"></a>
  <a href="https://lerna.js.org/"><img src="https://img.shields.io/badge/maintained%20with-lerna-cc00ff.svg?style=flat-square" alt="Maintained with Lerna"></a>
</p>

<p align="center">
  <a href="https://invertase.link/discord"><img src="https://img.shields.io/discord/295953187817521152.svg?style=flat-square&colorA=7289da&label=Chat%20on%20Discord" alt="Chat on Discord"></a>
  <a href="https://twitter.com/rnfirebase"><img src="https://img.shields.io/twitter/follow/rnfirebase.svg?style=flat-square&colorA=1da1f2&colorB=&label=Follow%20on%20Twitter" alt="Follow on Twitter"></a>
  <a href="https://www.facebook.com/groups/rnfirebase"><img src="https://img.shields.io/badge/Follow%20on%20Facebook-4172B8?logo=facebook&style=flat-square&logoColor=fff" alt="Follow on Facebook"></a>
</p>

---

Bring powerful machine learning vision APIs to your mobile app whether you're new or experienced in ML. Get started easily by using ready-to-use APIs from Firebase for common mobile use cases, or import your own custom models which can be hosted and served to your apps by Firebase. ML Kit APIs can run on-device or in the cloud, depending on the functionality, and some give you both choices.

This module currently supports the following Firebase ML Kit Vision APIs:

| API                                 | Cloud Model | On Device |
|-------------------------------------|-------------|-----------|
| [Text Recognition](https://firebase.google.com/docs/ml-kit/recognize-text)                    | ✅          | ✅        |
| [Document Text Recognition](https://firebase.google.com/docs/ml-kit/recognize-text))           | ✅          |           |
| [Face Detection](https://firebase.google.com/docs/ml-kit/detect-faces)                      |             | ✅        |
| [Barcode Scanning](https://firebase.google.com/docs/ml-kit/read-barcodes)                   |             | ✅        |
| [Image Labelling](https://firebase.google.com/docs/ml-kit/label-images)                     | ✅          | ✅        |
| [Landmark Recognition](https://firebase.google.com/docs/ml-kit/recognize-landmarks)                |             | ✅        |
| [AutoML Vision Edge](https://firebase.google.com/docs/ml-kit/automl-image-labeling)                  | ❌          | ❌        |
| [Object Detection/Tracking](https://firebase.google.com/docs/ml-kit/object-detection)           | ❌          | ❌        |
| Image Labelling (with [Custom Model]((https://firebase.google.com/docs/ml-kit/label-images))) | ❌          | ❌        |

[> Learn More](https://firebase.google.com/products/ml-kit/)

## Installation

Requires `@react-native-firebase/app` to be installed.

```bash
yarn add @react-native-firebase/ml-vision
```

## Documentation

- [Quick Start](https://rnfirebase.io/ml-vision/usage)
- [Reference](https://rnfirebase.io/reference/ml-vision)

### Additional Topics

- [Text Recognition](https://rnfirebase.io/ml-vision/text-recognition)
- [Landmark Recognition](https://rnfirebase.io/ml-vision/landmark-recognition)
- [Barcode Scanning](https://rnfirebase.io/ml-vision/barcode-scanning)
- [Image Labelling](https://rnfirebase.io/ml-vision/image-labelling)
- [Face Detection](https://rnfirebase.io/ml-vision/face-detection)



## License

- See [LICENSE](/LICENSE)

---

<p>
  <img align="left" width="75px" src="https://static.invertase.io/assets/invertase-logo-small.png">
  <p align="left">
    Built and maintained with 💛 by <a href="https://invertase.io">Invertase</a>.
  </p>
</p>

---

==> ml-vision-6.6.0.tgz: package/README.md <==
<p align="center">
  <a href="https://rnfirebase.io">
    <img width="160px" src="https://i.imgur.com/JIyBtKW.png"><br/>
  </a>
  <h2 align="center">React Native Firebase - ML Kit Vision</h2>
</p>

<p align="center">
  <a href="https://api.rnfirebase.io/coverage/ml-vision/detail"><img src="https://api.rnfirebase.io/coverage/ml-vision/badge?style=flat-square" alt="Coverage"></a>
  <a href="https://www.npmjs.com/package/@react-native-firebase/ml-vision"><img src="https://img.shields.io/npm/dm/@react-native-firebase/ml-vision.svg?style=flat-square" alt="NPM downloads"></a>
  <a href="https://www.npmjs.com/package/@react-native-firebase/ml-vision"><img src="https://img.shields.io/npm/v/@react-native-firebase/ml-vision.svg?style=flat-square" alt="NPM version"></a>
  <a href="/LICENSE"><img src="https://img.shields.io/npm/l/react-native-firebase.svg?style=flat-square" alt="License"></a>
  <a href="https://lerna.js.org/"><img src="https://img.shields.io/badge/maintained%20with-lerna-cc00ff.svg?style=flat-square" alt="Maintained with Lerna"></a>
</p>

<p align="center">
  <a href="https://invertase.link/discord"><img src="https://img.shields.io/discord/295953187817521152.svg?style=flat-square&colorA=7289da&label=Chat%20on%20Discord" alt="Chat on Discord"></a>
  <a href="https://twitter.com/rnfirebase"><img src="https://img.shields.io/twitter/follow/rnfirebase.svg?style=flat-square&colorA=1da1f2&colorB=&label=Follow%20on%20Twitter" alt="Follow on Twitter"></a>
  <a href="https://www.facebook.com/groups/rnfirebase"><img src="https://img.shields.io/badge/Follow%20on%20Facebook-4172B8?logo=facebook&style=flat-square&logoColor=fff" alt="Follow on Facebook"></a>
</p>

---

Bring powerful machine learning vision APIs to your mobile app whether you're new or experienced in ML. Get started easily by using ready-to-use APIs from Firebase for common mobile use cases, or import your own custom models which can be hosted and served to your apps by Firebase. ML Kit APIs can run on-device or in the cloud, depending on the functionality, and some give you both choices.

This module currently supports the following Firebase ML Kit Vision APIs:

| API                                 | Cloud Model | On Device |
|-------------------------------------|-------------|-----------|
| [Text Recognition](https://firebase.google.com/docs/ml-kit/recognize-text)                    | ✅          | ✅        |
| [Document Text Recognition](https://firebase.google.com/docs/ml-kit/recognize-text))           | ✅          |           |
| [Face Detection](https://firebase.google.com/docs/ml-kit/detect-faces)                      |             | ✅        |
| [Barcode Scanning](https://firebase.google.com/docs/ml-kit/read-barcodes)                   |             | ✅        |
| [Image Labeling](https://firebase.google.com/docs/ml-kit/label-images)                     | ✅          | ✅        |
| [Landmark Recognition](https://firebase.google.com/docs/ml-kit/recognize-landmarks)                |             | ✅        |
| [AutoML Vision Edge](https://firebase.google.com/docs/ml-kit/automl-image-labeling)                  | ❌          | ❌        |
| [Object Detection/Tracking](https://firebase.google.com/docs/ml-kit/object-detection)           | ❌          | ❌        |
| Image Labeling (with [Custom Model]((https://firebase.google.com/docs/ml-kit/label-images))) | ❌          | ❌        |

[> Learn More](https://firebase.google.com/products/ml-kit/)

## Installation

Requires `@react-native-firebase/app` to be installed.

```bash
yarn add @react-native-firebase/ml-vision
```

## Documentation

- [Quick Start](https://rnfirebase.io/ml-vision/usage)
- [Reference](https://rnfirebase.io/reference/ml-vision)

### Additional Topics

- [Text Recognition](https://rnfirebase.io/ml-vision/text-recognition)
- [Landmark Recognition](https://rnfirebase.io/ml-vision/landmark-recognition)
- [Barcode Scanning](https://rnfirebase.io/ml-vision/barcode-scanning)
- [Image Labeling](https://rnfirebase.io/ml-vision/image-labeling)
- [Face Detection](https://rnfirebase.io/ml-vision/face-detection)



## License

- See [LICENSE](/LICENSE)

---

<p>
  <img align="left" width="75px" src="https://static.invertase.io/assets/invertase-logo-small.png">
  <p align="left">
    Built and maintained with 💛 by <a href="https://invertase.io">Invertase</a>.
  </p>
</p>

---
